@@ -27,6 +27,7 @@
 #include "tables.h"
 #include "trinity.h"	// ARRAY_SIZE
 #include "uid.h"
+#include "udp.h"
 #include "utils.h"	// zmalloc
 
 enum childflags {
@@ -232,6 +233,17 @@ static void bind_child_to_cpu(struct childdata *child)
 	sched_setaffinity(pid, sizeof(set), &set);
 }
 
+static void log_child_spawned(pid_t pid, int childno)
+{
+	struct msg_childspawned childmsg;
+
+	if (logging_enabled == FALSE)
+		return;
+
+	init_msgchildhdr(&childmsg.hdr, CHILD_SPAWNED, pid, childno);
+	sendudp((char *) &childmsg, sizeof(childmsg));
+}
+
 /*
  * Called from the fork_children loop in the main process.
  */
@@ -240,6 +252,8 @@ static void init_child(struct childdata *child, int childno)
 	pid_t pid = getpid();
 	char childname[17];
 
+	log_child_spawned(pid, childno);
+
 	/* Wait for parent to set our childno */
 	while (pids[childno] != pid) {
 		/* Make sure parent is actually alive to wait for us. */
@@ -279,6 +293,14 @@ static void init_child(struct childdata *child, int childno)
 	mask_signals_child();
 
 	disable_coredumps();
+
+	if (RAND_BOOL()) {
+		unshare(CLONE_NEWNS);
+		unshare(CLONE_NEWIPC);
+		unshare(CLONE_IO);
+		unshare(CLONE_NEWNET);
+	}
+
 /*
 	if (shm->unshare_perm_err == FALSE) {
 		if (RAND_BOOL()) {
@@ -415,7 +437,10 @@ static bool handle_sigreturn(int sigwas)
 
 	if (sigwas != SIGALRM)
 		output(1, "[%d] Back from signal handler! (sig was %s)\n", getpid(), strsignal(sigwas));
-
+	else {
+		log_child_signalled(child->num, pids[child->num], SIGALRM, child->op_nr);
+		child->op_nr++;
+	}
 	return TRUE;
 }
 
@@ -504,6 +529,13 @@ void child_process(struct childdata *child, int childno)
 
 		if (ops->flags & ONESHOT)
 			loops = 0;
+
+		if (syscalls_todo) {
+			if (shm->stats.op_count >= syscalls_todo) {
+				shm->exit_reason = EXIT_REACHED_COUNT;
+				goto out;
+			}
+		}
 	}
 
 	enable_coredumps();
