@@ -13,10 +13,10 @@
 #include <unistd.h>
 #include "arch.h"	// page_size
 #include "child.h"
-#include "log.h"
 #include "pathnames.h"
 #include "pids.h"
 #include "random.h"
+#include "shm.h"
 
 static void read_pid_files(pid_t pid, char *buffer)
 {
