@@ -1,8 +1,6 @@
 /* DRM FDs */
 
-#include "config.h"
 #include "fd.h"
-#include "log.h"
 #include "memfd.h"
 #include "objects.h"
 #include "random.h"
@@ -25,11 +23,24 @@
 #include <fcntl.h>
 #include <drm/drm.h>
 
+#include "udp.h"
+
 static void drmfd_destructor(struct object *obj)
 {
 	close(obj->drmfd);
 }
 
+static void drmfd_dump(struct object *obj, bool global)
+{
+	struct msg_objcreateddrm objmsg;
+
+	output(2, "drmfd:%d\n", obj->drmfd);
+
+	init_msgobjhdr(&objmsg.hdr, OBJ_CREATED_DRM, global, obj);
+	objmsg.fd = obj->drmfd;
+	sendudp((char *) &objmsg, sizeof(objmsg));
+}
+
 static int create_dumb(__unused__ int fd)
 {
 #if defined(DRM_IOCTL_MODE_CREATE_DUMB) && defined(DRM_IOCTL_PRIME_HANDLE_TO_FD)
@@ -79,10 +90,11 @@ static int open_drm_fds(void)
 	int fd, dfd;
 	DIR *dir;
 	struct dirent *entry;
-	char buf[128];
+	char buf[256 + 10];
 
 	head = get_objhead(OBJ_GLOBAL, OBJ_FD_DRM);
 	head->destroy = &drmfd_destructor;
+	head->dump = &drmfd_dump;
 
 	dir = opendir("/dev/dri/");
 	if (!dir)
