@@ -9,23 +9,37 @@
 
 #include "fd.h"
 #include "files.h"
-#include "log.h"
 #include "objects.h"
 #include "random.h"
 #include "sanitise.h"
 #include "shm.h"
+#include "udp.h"
 #include "compat.h"
 
 static void eventfd_destructor(struct object *obj)
 {
-	close(obj->eventfd);
+	close(obj->eventfdobj.fd);
+}
+
+static void eventfd_dump(struct object *obj, bool global)
+{
+	struct eventfdobj *eo = &obj->eventfdobj;
+	struct msg_objcreatedeventfd objmsg;
+
+	output(2, "eventfd fd:%d count:%d flags:%x\n", eo->fd, eo->count, eo->flags);
+
+	init_msgobjhdr(&objmsg.hdr, OBJ_CREATED_EVENTFD, global, obj);
+	objmsg.fd = eo->fd;
+	objmsg.count = eo->count;
+	objmsg.flags = eo->flags;
+	sendudp((char *) &objmsg, sizeof(objmsg));
 }
 
 static int open_eventfd_fds(void)
 {
 	struct objhead *head;
 	unsigned int i;
-	unsigned int flags[] = {
+	const unsigned int flags[] = {
 		0,
 		EFD_NONBLOCK,
 		EFD_NONBLOCK | EFD_SEMAPHORE,
@@ -38,20 +52,22 @@ static int open_eventfd_fds(void)
 
 	head = get_objhead(OBJ_GLOBAL, OBJ_FD_EVENTFD);
 	head->destroy = &eventfd_destructor;
+	head->dump = &eventfd_dump;
 
 	for (i = 0; i < ARRAY_SIZE(flags); i++) {
 		struct object *obj;
 		int fd;
+		int count = rand32();
 
-		fd = eventfd(rand32(), flags[i]);
+		fd = eventfd(count, flags[i]);
 		if (fd < 0)
 			continue;
 
 		obj = alloc_object();
-		obj->eventfd = fd;
+		obj->eventfdobj.fd = fd;
+		obj->eventfdobj.count = count;
+		obj->eventfdobj.flags = flags[i];
 		add_object(obj, OBJ_GLOBAL, OBJ_FD_EVENTFD);
-
-		output(2, "fd[%d] = eventfd\n", fd);
 	}
 
 	return TRUE;
@@ -66,7 +82,7 @@ static int get_rand_eventfd_fd(void)
 		return -1;
 
 	obj = get_random_object(OBJ_FD_EVENTFD, OBJ_GLOBAL);
-	return obj->eventfd;
+	return obj->eventfdobj.fd;
 }
 
 static const struct fd_provider eventfd_fd_provider = {
