@@ -5,7 +5,6 @@
 #include <unistd.h>
 
 #include "fd.h"
-#include "log.h"
 #include "list.h"
 #include "net.h"
 #include "params.h"
@@ -20,6 +19,7 @@ static unsigned int num_fd_providers;			// num in list.
 static unsigned int num_fd_providers_to_enable = 0;	// num of --fd-enable= params
 static unsigned int num_fd_providers_enabled = 0;	// final num we enabled.
 static unsigned int num_fd_providers_initialized = 0;	// num we called ->init on
+static bool enable_fd_initialized = FALSE;		// initialized (disabled all) fd providers
 
 static struct fd_provider *fd_providers = NULL;
 
@@ -74,6 +74,9 @@ static void __open_fds(bool do_rand)
 			provider->initialized = TRUE;
 			num_fd_providers_initialized++;
 			num_fd_providers_enabled++;
+		} else {
+			outputstd("Error during initialization of %s\n", provider->name);
+			num_fd_providers_to_enable--;
 		}
 	}
 }
@@ -191,7 +194,7 @@ void process_fds_param(char *param, bool enable)
 
 	len = strlen(param);
 
-	if (enable == TRUE) {
+	if (enable_fd_initialized == FALSE && enable == TRUE) {
 		struct list_head *node;
 
 		/* First, pass through and mark everything disabled. */
@@ -201,14 +204,15 @@ void process_fds_param(char *param, bool enable)
 			provider = (struct fd_provider *) node;
 			provider->enabled = FALSE;
 		}
+		enable_fd_initialized = TRUE;
 	}
 
 	/* Check if there are any commas. If so, split them into multiple params,
 	 * validating them as we go.
 	 */
 	for (i = 0; i < len; i++) {
-		if (str[i] == ',') {
-			str[i] = 0;
+		if (str_orig[i] == ',') {
+			str_orig[i] = 0;
 			toggle_fds_param(str, enable);
 			str = str_orig + i + 1;
 		}
