@@ -8,17 +8,30 @@
 #include <sys/inotify.h>
 
 #include "fd.h"
-#include "log.h"
 #include "objects.h"
 #include "random.h"
 #include "sanitise.h"
 #include "shm.h"
+#include "udp.h"
 
 #define MAX_INOTIFY_FDS 5
 
 static void inotify_destructor(struct object *obj)
 {
-	close(obj->inotifyfd);
+	close(obj->inotifyobj.fd);
+}
+
+static void inotify_dump(struct object *obj, bool global)
+{
+	struct inotifyobj *io = &obj->inotifyobj;
+	struct msg_objcreatedinotify objmsg;
+
+	output(2, "inotify fd:%d flags:%x\n", io->fd, io->flags);
+
+	init_msgobjhdr(&objmsg.hdr, OBJ_CREATED_INOTIFY, global, obj);
+	objmsg.fd = io->fd;
+	objmsg.flags = io->flags;
+	sendudp((char *) &objmsg, sizeof(objmsg));
 }
 
 static int open_inotify_fds(void)
@@ -36,13 +49,15 @@ static int open_inotify_fds(void)
 
 	head = get_objhead(OBJ_GLOBAL, OBJ_FD_INOTIFY);
 	head->destroy = &inotify_destructor;
+	head->dump = &inotify_dump;
 
 	fd = inotify_init();
 	if (fd < 0)
 		return FALSE;
 
 	obj = alloc_object();
-	obj->inotifyfd = fd;
+	obj->inotifyobj.fd = fd;
+	obj->inotifyobj.flags = 0;
 	add_object(obj, OBJ_GLOBAL, OBJ_FD_INOTIFY);
 
 	for (i = 0; i < ARRAY_SIZE(flags); i++) {
@@ -51,7 +66,8 @@ static int open_inotify_fds(void)
 			return FALSE;
 
 		obj = alloc_object();
-		obj->inotifyfd = fd;
+		obj->inotifyobj.fd = fd;
+		obj->inotifyobj.flags = flags[i];
 		add_object(obj, OBJ_GLOBAL, OBJ_FD_INOTIFY);
 	}
 
@@ -67,7 +83,7 @@ static int get_rand_inotify_fd(void)
 		return -1;
 
 	obj = get_random_object(OBJ_FD_INOTIFY, OBJ_GLOBAL);
-	return obj->inotifyfd;
+	return obj->inotifyobj.fd;
 }
 
 static const struct fd_provider inotify_fd_provider = {
