@@ -10,7 +10,6 @@
 
 #include "debug.h"
 #include "domains.h"
-#include "log.h"
 #include "net.h"
 #include "objects.h"
 #include "params.h"	// verbose, do_specific_domain
@@ -18,6 +17,7 @@
 #include "sanitise.h"
 #include "shm.h"
 #include "trinity.h"
+#include "udp.h"
 #include "uid.h"
 #include "utils.h"
 
@@ -60,7 +60,7 @@ retry:
 		free((void *) so->optval);
 }
 
-static struct object * add_socket(int fd, unsigned int domain, unsigned int type, unsigned int protocol, bool accepted)
+static struct object * add_socket(int fd, unsigned int domain, unsigned int type, unsigned int protocol)
 {
 	struct object *obj;
 
@@ -73,14 +73,10 @@ static struct object * add_socket(int fd, unsigned int domain, unsigned int type
 
 	add_object(obj, OBJ_GLOBAL, OBJ_FD_SOCKET);
 
-	output(2, "fd[%i] = domain:%u (%s) type:0x%u protocol:%u %s\n",
-		fd, domain, get_domain_name(domain), type, protocol,
-		accepted ? "[accepted]" : "");
-
 	return obj;
 }
 
-int open_socket(unsigned int domain, unsigned int type, unsigned int protocol)
+static int open_socket(unsigned int domain, unsigned int type, unsigned int protocol)
 {
 	struct object *obj;
 	struct sockaddr *sa = NULL;
@@ -93,13 +89,17 @@ int open_socket(unsigned int domain, unsigned int type, unsigned int protocol)
 	if (fd == -1)
 		return fd;
 
-	obj = add_socket(fd, domain, type, protocol, FALSE);
+	obj = add_socket(fd, domain, type, protocol);
 
 	proto = net_protocols[domain].proto;
 	if (proto != NULL)
 		if (proto->socket_setup != NULL)
 			proto->socket_setup(fd);
 
+	// FIXME:
+	// All of this needs to be broken out into child ops instead of
+	// special casing it all at creation time.
+
 	/* Set some random socket options. */
 	sso_socket(&obj->sockinfo.triplet, &so, fd);
 
@@ -122,7 +122,7 @@ int open_socket(unsigned int domain, unsigned int type, unsigned int protocol)
 
 //		ret = accept4(fd, sa, &salen, SOCK_NONBLOCK);
 //		if (ret != -1) {
-//			obj = add_socket(ret, domain, type, protocol, TRUE);
+//			obj = add_socket(ret, domain, type, protocol);
 //			nr_sockets++;
 //		}
 	}
@@ -150,7 +150,7 @@ static void lock_cachefile(int type)
 
 	if (fcntl(cachefile, F_SETLKW, &fl) == -1) {
 		perror("fcntl F_SETLKW");
-		exit(EXIT_FAILURE);
+		return;
 	}
 
 	if (verbose)
@@ -170,7 +170,7 @@ static void unlock_cachefile(void)
 
 	if (fcntl(cachefile, F_SETLK, &fl) == -1) {
 		perror("fcntl F_UNLCK F_SETLK ");
-		exit(EXIT_FAILURE);
+		return;
 	}
 
 	if (verbose)
@@ -184,56 +184,39 @@ static unsigned int valid_proto(unsigned int family)
 	famstr = get_domain_name(family);
 
 	/* Not used for creating sockets. */
-	if (strncmp(famstr, "PF_UNSPEC", 9) == 0)
+	if (strncmp(famstr, "UNSPEC", 9) == 0)
 		return FALSE;
-	if (strncmp(famstr, "PF_BRIDGE", 9) == 0)
+	if (strncmp(famstr, "BRIDGE", 9) == 0)
 		return FALSE;
-	if (strncmp(famstr, "PF_SECURITY", 11) == 0)
+	if (strncmp(famstr, "SECURITY", 11) == 0)
 		return FALSE;
 
 	/* Not actually implemented (or now removed). */
-	if (strncmp(famstr, "PF_NETBEUI", 10) == 0)
+	if (strncmp(famstr, "NETBEUI", 10) == 0)
 		return FALSE;
-	if (strncmp(famstr, "PF_ASH", 6) == 0)
+	if (strncmp(famstr, "ASH", 6) == 0)
 		return FALSE;
-	if (strncmp(famstr, "PF_ECONET", 9) == 0)
+	if (strncmp(famstr, "ECONET", 9) == 0)
 		return FALSE;
-	if (strncmp(famstr, "PF_SNA", 6) == 0)
+	if (strncmp(famstr, "SNA", 6) == 0)
 		return FALSE;
-	if (strncmp(famstr, "PF_WANPIPE", 10) == 0)
+	if (strncmp(famstr, "WANPIPE", 10) == 0)
 		return FALSE;
 
 	/* Needs root. */
 	if (orig_uid != 0) {
-		if (strncmp(famstr, "PF_KEY", 6) == 0)
+		if (strncmp(famstr, "KEY", 6) == 0)
 			return FALSE;
-		if (strncmp(famstr, "PF_PACKET", 9) == 0)
+		if (strncmp(famstr, "PACKET", 9) == 0)
 			return FALSE;
-		if (strncmp(famstr, "PF_LLC", 6) == 0)
+		if (strncmp(famstr, "LLC", 6) == 0)
 			return FALSE;
 	}
 
 	return TRUE;
 }
 
-void generate_socket(unsigned int family, unsigned int protocol, unsigned int type)
-{
-	struct socket_triplet st;
-	int fd;
-
-	st.family = family;
-	st.type = type;
-	st.protocol = protocol;
-
-	fd = open_socket(st.family, st.type, st.protocol);
-	if (fd > -1) {
-		write_socket_to_cache(&st);
-		return;
-	}
-	output(0, "Couldn't open socket %d:%d:%d. %s\n", family, type, protocol, strerror(errno));
-}
-
-bool write_socket_to_cache(struct socket_triplet *st)
+static bool write_socket_to_cache(struct socket_triplet *st)
 {
 	unsigned int buffer[3];
 	int n;
@@ -252,6 +235,24 @@ bool write_socket_to_cache(struct socket_triplet *st)
 	return TRUE;
 }
 
+static bool generate_socket(unsigned int family, unsigned int protocol, unsigned int type)
+{
+	struct socket_triplet st;
+	int fd;
+
+	st.family = family;
+	st.type = type;
+	st.protocol = protocol;
+
+	fd = open_socket(st.family, st.type, st.protocol);
+	if (fd > -1) {
+		write_socket_to_cache(&st);
+		return TRUE;
+	}
+	output(2, "Couldn't open socket %d:%d:%d. %s\n", family, type, protocol, strerror(errno));
+	return FALSE;
+}
+
 static bool generate_specific_socket(int family)
 {
 	struct socket_triplet st;
@@ -302,8 +303,12 @@ static bool generate_sockets(void)
 	lock_cachefile(F_WRLCK);
 
 	if (do_specific_domain == TRUE) {
-		while (nr_sockets < NR_SOCKET_FDS)
-			ret |= generate_specific_socket(specific_domain);
+		while (nr_sockets < NR_SOCKET_FDS) {
+			ret = generate_specific_socket(specific_domain);
+
+			if (ret == FALSE)
+				return FALSE;
+		}
 		goto out_unlock;
 	}
 
@@ -343,7 +348,7 @@ static bool generate_sockets(void)
 
 		triplets = proto->valid_triplets;
 		for (j = 0; j < proto->nr_triplets; j++)
-			generate_socket(triplets[j].family, triplets[j].protocol, triplets[j].type);
+			ret |= generate_socket(triplets[j].family, triplets[j].protocol, triplets[j].type);
 
 		if (proto->nr_privileged_triplets == 0)
 			continue;
@@ -353,7 +358,7 @@ static bool generate_sockets(void)
 
 		triplets = proto->valid_privileged_triplets;
 		for (j = 0; j < proto->nr_privileged_triplets; j++)
-			generate_socket(triplets[j].family, triplets[j].protocol, triplets[j].type);
+			ret |= generate_socket(triplets[j].family, triplets[j].protocol, triplets[j].type);
 	}
 
 	/* This is here temporarily until we have sufficient ->valid_proto's */
@@ -401,6 +406,23 @@ static void socket_destructor(struct object *obj)
 			strerror(errno));
 }
 
+static void socket_dump(struct object *obj, bool global)
+{
+	struct socketinfo *si = &obj->sockinfo;
+	struct msg_objcreatedsocket objmsg;
+
+	output(2, "socket fd:%d domain:%u (%s) type:0x%u protocol:%u\n",
+		si->fd, si->triplet.family, get_domain_name(si->triplet.family),
+		si->triplet.type, si->triplet.protocol);
+
+	init_msgobjhdr(&objmsg.hdr, OBJ_CREATED_SOCKET, global, obj);
+	objmsg.si.fd = si->fd;
+	objmsg.si.triplet.family = si->triplet.family;
+	objmsg.si.triplet.type = si->triplet.type;
+	objmsg.si.triplet.protocol = si->triplet.protocol;
+	sendudp((char *) &objmsg, sizeof(objmsg));
+}
+
 static int open_sockets(void)
 {
 	struct objhead *head;
@@ -409,6 +431,7 @@ static int open_sockets(void)
 
 	head = get_objhead(OBJ_GLOBAL, OBJ_FD_SOCKET);
 	head->destroy = &socket_destructor;
+	head->dump = &socket_dump;
 
 	cachefile = open(cachefilename, O_RDONLY);
 	if (cachefile < 0) {
