@@ -10,7 +10,6 @@
 
 #include "fd.h"
 #include "files.h"
-#include "log.h"
 #include "objects.h"
 #include "random.h"
 #include "sanitise.h"
@@ -18,41 +17,65 @@
 #include "syscalls/syscalls.h"
 #include "testfile.h"
 #include "utils.h"
+#include "udp.h"
 
 #define MAX_TESTFILES 4
 #define MAX_TESTFILE_FDS 20
 
 static void testfile_destructor(struct object *obj)
 {
-	close(obj->testfilefd);
+	close(obj->testfileobj.fd);
 }
 
-static int open_testfile(char *filename)
+static void testfile_dump(struct object *obj, bool global)
+{
+	struct fileobj *fo = &obj->testfileobj;
+	struct msg_objcreatedfile objmsg;
+	int len = strlen(fo->filename);
+
+	output(2, "testfile fd:%d filename:%s flags:%x fopened:%d fcntl_flags:%x\n",
+		fo->fd, fo->filename, fo->flags, fo->fopened, fo->fcntl_flags);
+
+	init_msgobjhdr(&objmsg.hdr, OBJ_CREATED_TESTFILE, global, obj);
+	strncpy(objmsg.filename, fo->filename, len);
+	memset(objmsg.filename + len, 0, MAX_PATH_LEN - len);
+	objmsg.flags = fo->flags;
+	objmsg.fd = fo->fd;
+	objmsg.fopened = fo->fopened;
+	objmsg.fcntl_flags = fo->fcntl_flags;
+	sendudp((char *) &objmsg, sizeof(objmsg));
+}
+
+static int open_testfile(struct object *obj, char *filename)
 {
-	struct objhead *head;
 	int fd;
 
-	head = get_objhead(OBJ_GLOBAL, OBJ_FD_TESTFILE);
-	head->destroy = &testfile_destructor;
+	obj->testfileobj.filename = filename;
 
 	/* file might be around from an earlier run, nuke it. */
 	(void) unlink(filename);
 
 	if (RAND_BOOL()) {
-		fd = open_with_fopen(filename, O_RDWR);
-		if (fd != -1) {
-			output(2, "fd[%d] = fopen(\"%s\", O_RDWR)\n", fd, filename);
-			(void) fcntl(fd, F_SETFL, random_fcntl_setfl_flags());
-		}
-	} else {
 		const unsigned long open_flags[] = { O_DIRECT, O_DSYNC, O_SYNC, };
 		int flags = 0;
 
 		flags = set_rand_bitmask(ARRAY_SIZE(open_flags), open_flags);;
-
+		obj->testfileobj.flags = O_CREAT | flags;
 		fd = open(filename, O_CREAT | flags, 0666);
-		if (fd != -1)
-			output(2, "fd[%d] = open(\"%s\", flags:%x)\n", fd, filename, flags);	//TODO: decode flags
+		obj->testfileobj.fopened = FALSE;
+		obj->testfileobj.fcntl_flags = 0;
+	} else {
+		obj->testfileobj.fopened = TRUE;
+		obj->testfileobj.flags = O_RDWR;
+
+		fd = open_with_fopen(filename, O_RDWR);
+		if (fd != -1) {
+			int fcntl_flags;
+
+			fcntl_flags = random_fcntl_setfl_flags();
+			(void) fcntl(fd, F_SETFL, fcntl_flags);
+			obj->testfileobj.fcntl_flags = fcntl_flags;
+		}
 	}
 
 	return fd;
@@ -60,10 +83,16 @@ static int open_testfile(char *filename)
 
 static int open_testfile_fds(void)
 {
+	struct objhead *head;
+	struct object *obj = NULL;
 	char *filename;
 	unsigned int i = 1, nr = 0;
 	unsigned int fails = 0;
 
+	head = get_objhead(OBJ_GLOBAL, OBJ_FD_TESTFILE);
+	head->destroy = &testfile_destructor;
+	head->dump = &testfile_dump;
+
 	filename = zmalloc(64);
 
 	while (nr < MAX_TESTFILE_FDS) {
@@ -71,12 +100,13 @@ static int open_testfile_fds(void)
 
 		sprintf(filename, "trinity-testfile%u", i);
 
-		fd = open_testfile(filename);
-		if (fd != -1) {
-			struct object *obj;
-
+		if (obj == NULL)
 			obj = alloc_object();
-			obj->testfilefd = fd;
+
+		fd = open_testfile(obj, filename);
+		if (fd != -1) {
+
+			obj->testfileobj.fd = fd;
 			add_object(obj, OBJ_GLOBAL, OBJ_FD_TESTFILE);
 
 			i++;
@@ -86,6 +116,8 @@ static int open_testfile_fds(void)
 
 			fails = 0;
 
+			obj = NULL;	// Make it alloc a new one.
+
 			mmap_fd(fd, filename, page_size, PROT_READ|PROT_WRITE, OBJ_GLOBAL, OBJ_MMAP_TESTFILE);
 
 		} else {
@@ -96,8 +128,6 @@ static int open_testfile_fds(void)
 		}
 	}
 
-	dump_objects(OBJ_GLOBAL, OBJ_MMAP_TESTFILE);
-
 	free(filename);
 	return TRUE;
 }
@@ -111,7 +141,7 @@ int get_rand_testfile_fd(void)
 		return -1;
 
 	obj = get_random_object(OBJ_FD_TESTFILE, OBJ_GLOBAL);
-	return obj->testfilefd;
+	return obj->testfileobj.fd;
 }
 
 static const struct fd_provider testfile_fd_provider = {
