@@ -1,5 +1,7 @@
 #pragma once
 
+#include <sys/socket.h>
+
 /* bits/eventfd.h */
 #ifndef EFD_SEMAPHORE
 #define EFD_SEMAPHORE 1
@@ -136,6 +138,12 @@ enum {
 #ifndef MADV_DODUMP
 #define MADV_DODUMP 17
 #endif
+#ifndef MADV_WIPEONFORK
+#define MADV_WIPEONFORK 18
+#endif
+#ifndef MADV_KEEPONFORK
+#define MADV_KEEPONFORK 19
+#endif
 
 
 /* bits/socket.h */
@@ -225,6 +233,14 @@ enum {
 #define PF_KCM		41
 #endif
 
+#ifndef PF_QIPCRTR
+#define PF_QIPCRTR	42
+#endif
+
+#ifndef PF_SMC
+#define PF_SMC		43
+#endif
+
 #ifndef NFC_SOCKPROTO_RAW
 #define NFC_SOCKPROTO_RAW	0
 #endif
@@ -240,6 +256,10 @@ enum {
 #define MSG_BATCH 0x40000
 #endif
 
+#ifndef MSG_ZEROCOPY
+#define MSG_ZEROCOPY	0x4000000
+#endif
+
 #ifndef MSG_CMSG_CLOEXEC
 #define MSG_CMSG_CLOEXEC	0x40000000
 #endif
@@ -267,6 +287,9 @@ enum {
 #ifndef NETLINK_CRYPTO
 #define NETLINK_CRYPTO 21
 #endif
+#ifndef NETLINK_SMC
+#define NETLINK_SMC 22
+#endif
 #ifndef NETLINK_RX_RING
 #define NETLINK_RX_RING 6
 #define NETLINK_TX_RING 7
@@ -301,6 +324,9 @@ enum {
 #ifndef RTNLGRP_NSID
 #define RTNLGRP_NSID 28
 #endif
+#ifndef RTNLGRP_MPLS_NETCONF
+#define RTNLGRP_MPLS_NETCONF 29
+#endif
 
 /* linux/prctl.h */
 #ifndef PR_MCE_KILL_GET
@@ -485,6 +511,35 @@ enum kcmp_type {
 #define SO_CNX_ADVICE 53
 #endif
 
+#ifndef SCM_TIMESTAMPING_OPT_STATS
+#define SCM_TIMESTAMPING_OPT_STATS      54
+#endif
+
+#ifndef SO_MEMINFO
+#define SO_MEMINFO              55
+#endif
+
+#ifndef SO_INCOMING_NAPI_ID
+#define SO_INCOMING_NAPI_ID     56
+#endif
+
+#ifndef SO_COOKIE
+#define SO_COOKIE               57
+#endif
+
+#ifndef SCM_TIMESTAMPING_PKTINFO
+#define SCM_TIMESTAMPING_PKTINFO        58
+#endif
+
+#ifndef SO_PEERGROUPS
+#define SO_PEERGROUPS           59
+#endif
+
+#ifndef SO_ZEROCOPY
+#define SO_ZEROCOPY	60
+#endif
+
+
 /* linux/tcp.h */
 #ifndef TCP_COOKIE_TRANSACTIONS
 #define TCP_COOKIE_TRANSACTIONS	15
@@ -543,6 +598,18 @@ enum kcmp_type {
 #define TCP_REPAIR_WINDOW	29
 #endif
 
+#ifndef TCP_FASTOPEN_CONNECT
+#define TCP_FASTOPEN_CONNECT	30
+#endif
+
+#ifndef TCP_ULP
+#define TCP_ULP			31
+#endif
+
+#ifndef TCP_MD5SIG_EXT
+#define TCP_MD5SIG_EXT		32
+#endif
+
 /* linux/if_packet.h */
 #ifndef PACKET_VNET_HDR
 #define PACKET_VNET_HDR		15
@@ -614,6 +681,9 @@ enum kcmp_type {
 #ifndef IP_BIND_ADDRESS_NO_PORT
 #define IP_BIND_ADDRESS_NO_PORT	24
 #endif
+#ifndef IP_RECVFRAGSIZE
+#define IP_RECVFRAGSIZE		25
+#endif
 #ifndef IP_MULTICAST_ALL
 #define IP_MULTICAST_ALL	49
 #endif
@@ -662,7 +732,13 @@ enum kcmp_type {
 #define IPV6_UNICAST_IF         76
 #endif
 
+#ifndef IPV6_RECVFRAGSIZE
+#define IPV6_RECVFRAGSIZE       77
+#endif
 
+#ifndef IPV6_HDRINCL
+#define IPV6_HDRINCL		36
+#endif
 
 /* asm/resource.h */
 #ifndef RLIMIT_RTTIME
@@ -743,6 +819,10 @@ enum kcmp_type {
 #define SOL_RFCOMM      18
 #endif
 
+#ifndef SOL_TLS
+#define SOL_TLS		282
+#endif
+
 /* net/bluetooth/hci.h */
 #ifndef HCI_DATA_DIR
 #define HCI_DATA_DIR    1
@@ -770,7 +850,6 @@ enum kcmp_type {
 
 /* linux/nfc.h */
 #ifndef sockaddr_nfc
-#include <bits/sockaddr.h>
 #include <linux/types.h>
 
 struct sockaddr_nfc {
