@@ -1,8 +1,8 @@
-#ifndef TRINITY_IOCTLS_H
-#define TRINITY_IOCTLS_H
+#pragma once
 
 #include <stdlib.h>
 #include <sys/stat.h>
+#include "syscall.h"
 
 struct ioctl {
 	const char *name;
@@ -20,7 +20,7 @@ struct ioctl_group {
 
 	/* Non-NULL sanitise routine for this ioctl group. Initialize to
 	 * "pick_random_ioctl" to pick one random ioctl. */
-	void (*sanitise)(const struct ioctl_group *, int childno);
+	void (*sanitise)(const struct ioctl_group *, struct syscallrecord *rec);
 
 	/* Plug the available ioctls here. */
 	const struct ioctl *ioctls;
@@ -45,7 +45,7 @@ const struct ioctl_group *find_ioctl_group(int fd);
 
 const struct ioctl_group *get_random_ioctl_group(void);
 
-void pick_random_ioctl(const struct ioctl_group *, int childno);
+void pick_random_ioctl(const struct ioctl_group *, struct syscallrecord *rec);
 
 void dump_ioctls(void);
 
@@ -57,4 +57,3 @@ void dump_ioctls(void);
 		register_ioctl_group(&_struct); \
 	}
 
-#endif /* TRINITY_IOCTLS_H */
