@@ -15,10 +15,7 @@ extern unsigned int specific_domain;
 
 /* glibc headers might be older than the kernel, so chances are we know
  * about more protocols than glibc does. So we define our own PF_MAX */
-#define TRINITY_PF_MAX 42
-
-#define TYPE_MAX 10
-#define PROTO_MAX 256
+#define TRINITY_PF_MAX 44
 
 #define PF_NOHINT (-1)
 
@@ -51,10 +48,6 @@ struct protoptr {
 };
 extern const struct protoptr net_protocols[TRINITY_PF_MAX];
 
-void generate_socket(unsigned int family, unsigned int protocol, unsigned int type);
-int open_socket(unsigned int domain, unsigned int type, unsigned int protocol);
-bool write_socket_to_cache(struct socket_triplet *st);
-
 struct socketinfo * get_rand_socketinfo(void);
 int fd_from_socketinfo(struct socketinfo *si);
 
@@ -104,6 +97,8 @@ extern const struct netproto proto_iucv;
 extern const struct netproto proto_rxrpc;
 extern const struct netproto proto_phonet;
 extern const struct netproto proto_kcm;
+extern const struct netproto proto_qipcrtr;
+extern const struct netproto proto_smc;
 
 /* bpf */
 void bpf_gen_filter(unsigned long **addr, unsigned long *addrlen);
