@@ -1,6 +1,6 @@
 #pragma once
 
-/* Syscalls from arch/x86/syscalls/syscall_32.tbl */
+/* Syscalls from arch/x86/entry/syscalls/syscall_32.tbl */
 
 #include "sanitise.h"
 #include "syscall.h"
@@ -391,4 +391,8 @@ struct syscalltable syscalls_i386[] = {
 	{ .entry = &syscall_copy_file_range },
 	{ .entry = &syscall_preadv2 },
 	{ .entry = &syscall_pwritev2 },
+	{ .entry = &syscall_pkey_mprotect },
+	{ .entry = &syscall_pkey_alloc },
+	{ .entry = &syscall_pkey_free },
+	{ .entry = &syscall_statx },
 };
