@@ -11,6 +11,7 @@
 
 #include "child.h"
 #include "debug.h"
+#include "ftrace.h"
 #include "log.h"
 #include "params.h"
 #include "pids.h"
@@ -21,6 +22,7 @@
 #include "tables.h"
 #include "taint.h"
 #include "trinity.h"
+#include "udp.h"
 
 static void handle_child(int childno, pid_t childpid, int childstatus);
 
@@ -86,7 +88,10 @@ static int shm_is_corrupt(void)
  */
 void reap_child(struct childdata *child)
 {
-	child->tp = (struct timespec){};
+	/* Don't reap a child again */
+	if( pids[child->num] == EMPTY_PIDSLOT )
+		return;
+	child->tp = (struct timespec){ .tv_sec = 0, .tv_nsec = 0 };
 	unlock(&child->syscall.lock);
 	shm->running_childs--;
 	pids[child->num] = EMPTY_PIDSLOT;
@@ -207,6 +212,7 @@ unsigned int check_if_fd(struct childdata *child, struct syscallrecord *rec)
 		if (fd <= (unsigned int) fileno(child->logfile))
 			return FALSE;
 	}
+
 	return TRUE;
 }
 
@@ -238,6 +244,8 @@ static char get_pid_state(struct childdata *child)
 		BUG("get_pid_state can only be called from main!\n");
 
 	fseek(child->pidstatfile, 0L, SEEK_SET);
+	fflush(child->pidstatfile);
+
 	if (getline(&line, &n, child->pidstatfile) != -1)
 		sscanf(line, "%d %s %c", &pid, procname, &state);
 
@@ -261,7 +269,7 @@ static void dump_pid_stack(int pid)
 
 	while (!(feof(fp))) {
 		size_t n = 0;
-		char *line;
+		char *line = NULL;
 		if (getline(&line, &n, fp) != -1) {
 			output(0, "pid %d stack: %s", pid, line);
 			free(line);
@@ -503,6 +511,17 @@ static void fork_children(void)
 	shm->ready = TRUE;
 }
 
+void log_child_signalled(int childno, pid_t pid, int sig, unsigned long op_nr)
+{
+	struct msg_childsignalled childmsg;
+
+	init_msgchildhdr(&childmsg.hdr, CHILD_SIGNALLED, pid, childno);
+	childmsg.sig = sig;
+	childmsg.op_nr = op_nr;
+
+	sendudp((char *) &childmsg, sizeof(childmsg));
+}
+
 static void handle_childsig(int childno, int childstatus, bool stop)
 {
 	struct childdata *child;
@@ -537,12 +556,15 @@ static void handle_childsig(int childno, int childstatus, bool stop)
 	case SIGPIPE:
 	case SIGABRT:
 	case SIGBUS:
+	case SIGILL:
 		if (stop == TRUE)
 			debugf("Child %d (pid %d) was stopped by %s\n",
 					childno, pid, strsignal(WSTOPSIG(childstatus)));
-		else
+		else {
 			debugf("got a signal from child %d (pid %d) (%s)\n",
 					childno, pid, strsignal(WTERMSIG(childstatus)));
+			log_child_signalled(childno, pid, WTERMSIG(childstatus), child->op_nr);
+		}
 		reap_child(shm->children[childno]);
 
 		fclose(child->pidstatfile);
@@ -565,6 +587,16 @@ static void handle_childsig(int childno, int childstatus, bool stop)
 	}
 }
 
+static void log_child_exited(struct childdata *child)
+{
+	struct msg_childexited childmsg;
+
+	init_msgchildhdr(&childmsg.hdr, CHILD_EXITED,
+			 pids[child->num], child->num);
+	childmsg.op_nr = child->op_nr;
+	sendudp((char *) &childmsg, sizeof(childmsg));
+}
+
 static void handle_child(int childno, pid_t childpid, int childstatus)
 {
 	switch (childpid) {
@@ -573,39 +605,14 @@ static void handle_child(int childno, pid_t childpid, int childstatus)
 		break;
 
 	case -1:
-		if (shm->exit_reason != STILL_RUNNING)
-			return;
-
-		if (errno == ECHILD) {
-			unsigned int i;
-			bool seen = FALSE;
-
-			debugf("All children exited (childpid:%u)!\n", childpid);
-
-			for_each_child(i) {
-				pid_t pid = pids[i];
-				if (pid != EMPTY_PIDSLOT) {
-					if (pid_alive(pid) == FALSE) {
-						pids[i] = EMPTY_PIDSLOT;
-						shm->running_childs--;
-						replace_child(i);
-					} else {
-						debugf("%d looks still alive! ignoring.\n", pid);
-					}
-					seen = TRUE;
-				}
-			}
-			if (seen == FALSE)
-				shm->running_childs = 0;
-			break;
-		}
-		output(0, "error! (%s)\n", strerror(errno));
 		break;
 
 	default:
 		if (WIFEXITED(childstatus)) {
 			struct childdata *child = shm->children[childno];
 
+			log_child_exited(child);
+
 			debugf("Child %d (pid:%u type:%u) exited after %ld operations.\n",
 				childno, childpid, child->type, child->op_nr);
 			reap_child(shm->children[childno]);
@@ -670,31 +677,6 @@ static void handle_children(void)
 	}
 }
 
-static const char *reasons[NUM_EXIT_REASONS] = {
-	"Still running.",
-	"No more syscalls enabled.",
-	"Completed maximum number of operations.",
-	"No file descriptors open.",
-	"Lost track of a child.",
-	"shm corruption - Found a pid out of range.",
-	"ctrl-c",
-	"kernel became tainted.",
-	"SHM was corrupted!",
-	"Child reparenting problem",
-	"No files in file list.",
-	"Main process disappeared.",
-	"UID changed.",
-	"Something happened during fd init.",
-	"fork() failure",
-	"some kind of locking catastrophe",
-	"error while opening logfiles",
-};
-
-const char * decode_exit(void)
-{
-	return reasons[shm->exit_reason];
-}
-
 static unsigned int stall_count;
 
 static void check_children_progressing(void)
@@ -737,9 +719,51 @@ static void print_stats(void)
 	}
 }
 
+static bool handled_taint = FALSE;
+
+static void taint_check(void)
+{
+	if (handled_taint == TRUE)
+		return;
+
+	if (is_tainted() == TRUE) {
+		stop_ftrace();
+		tainted_postmortem();
+		handled_taint = TRUE;
+	}
+}
+
+static void log_main_started(void)
+{
+	struct msg_mainstarted mainmsg;
+
+	if (logging_enabled == FALSE)
+		return;
+
+	init_msghdr(&mainmsg.hdr, MAIN_STARTED);
+	mainmsg.shm_begin = shm;
+	mainmsg.shm_end = shm + shm_size - 1;
+	mainmsg.initial_seed = shm->seed;
+
+	sendudp((char *) &mainmsg, sizeof(mainmsg));
+}
+
+static void log_main_exiting(void)
+{
+	struct msg_mainexiting mainmsg;
+
+	if (logging_enabled == FALSE)
+		return;
+
+	init_msghdr(&mainmsg.hdr, MAIN_EXITING);
+	mainmsg.reason = shm->exit_reason;
+
+	sendudp((char *) &mainmsg, sizeof(mainmsg));
+}
+
 void main_loop(void)
 {
-	int ret = 0;
+	log_main_started();
 
 	fork_children();
 
@@ -747,11 +771,16 @@ void main_loop(void)
 
 		handle_children();
 
+		taint_check();
+
 		if (shm_is_corrupt() == TRUE)
 			goto corrupt;
 
-		while (check_all_locks() == TRUE)
+		while (check_all_locks() == TRUE) {
 			reap_dead_kids();
+			if (shm->exit_reason == EXIT_REACHED_COUNT)
+				kill_all_kids();
+		}
 
 		if (syscalls_todo && (shm->stats.op_count >= syscalls_todo)) {
 			output(0, "Reached limit %d. Telling children to exit.\n", syscalls_todo);
@@ -760,13 +789,6 @@ void main_loop(void)
 
 		check_children_progressing();
 
-		/* Only check taint if the mask allows it */
-		if (kernel_taint_mask != 0) {
-			ret = check_tainted();
-			if (((ret & kernel_taint_mask) & (~kernel_taint_initial)) != 0)
-				tainted_postmortem(ret);
-		}
-
 		print_stats();
 
 		/* This should never happen, but just to catch corner cases, like if
@@ -797,18 +819,22 @@ void main_loop(void)
 
 		/* Wait for all the children to exit. */
 		while (shm->running_childs > 0) {
+			taint_check();
+
 			handle_children();
 			kill_all_kids();
 			/* Give children a chance to exit before retrying. */
 			sleep(1);
 		}
+		reap_dead_kids();
 	}
 
 corrupt:
 	kill_all_kids();
 
 dont_wait:
-	output(0, "Bailing main loop because %s.\n", decode_exit());
+	output(0, "Bailing main loop because %s.\n", decode_exit(shm->exit_reason));
+	log_main_exiting();
 }
 
 
