@@ -11,6 +11,7 @@
 #include "random.h"
 #include "shm.h"
 #include "utils.h"
+#include "udp.h"
 
 /*
  * Return a pointer a previous mmap() that we did, either during startup,
@@ -59,6 +60,29 @@ void map_destructor(struct object *obj)
 	free(map->name);
 }
 
+void map_dump(struct object *obj, bool global)
+{
+	struct map *m;
+	struct msg_objcreatedmap objmsg;
+	char buf[11];
+	int len;
+
+	m = &obj->map;
+
+	init_msgobjhdr(&objmsg.hdr, OBJ_CREATED_MAP, global, obj);
+	objmsg.start = m->ptr;
+	len = strlen(m->name);
+	strncpy(objmsg.name, m->name, len);
+	memset(objmsg.name + len, 0, MAPS_NAME_MAX_LEN - len);
+	objmsg.prot = m->prot;
+	objmsg.type = m->type;
+	objmsg.size = m->size;
+	sendudp((char *) &objmsg, sizeof(objmsg));
+
+	sizeunit(m->size, buf);
+	output(2, " start: %p size:%s  name: %s\n", m->ptr, buf, m->name);
+}
+
 /*
  * Set up a childs local mapping list.
  * A child inherits the initial mappings, and will add to them
@@ -71,6 +95,7 @@ void init_child_mappings(void)
 
 	head = get_objhead(OBJ_LOCAL, OBJ_MMAP_ANON);
 	head->destroy = &map_destructor;
+	head->dump = &map_dump;
 
 	globallist = shm->global_objects[OBJ_MMAP_ANON].list;
 
@@ -160,6 +185,7 @@ void dirty_random_mapping(void)
  */
 void mmap_fd(int fd, const char *name, size_t len, int prot, bool global, enum objecttype type)
 {
+	struct objhead *head;
 	struct object *obj;
 	off_t offset;
 	int retries = 0;
@@ -189,6 +215,9 @@ retry_mmap:
 			goto retry_mmap;
 	}
 
+	head = get_objhead(global, type);
+	head->dump = &map_dump;
+
 	add_object(obj, global, type);
 	return;
 }
