@@ -9,7 +9,7 @@
 #include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
-void decnet_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
+static void decnet_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 {
 	struct sockaddr_dn *dn;
 	unsigned int i;
@@ -17,29 +17,18 @@ void decnet_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	dn = zmalloc(sizeof(struct sockaddr_dn));
 
 	dn->sdn_family = PF_DECnet;
-	dn->sdn_flags = rand();
-	dn->sdn_objnum = rand();
-	dn->sdn_objnamel = rand() % 16;
+	dn->sdn_flags = rnd();
+	dn->sdn_objnum = rnd();
+	dn->sdn_objnamel = rnd() % 16;
 	for (i = 0; i < dn->sdn_objnamel; i++)
-		dn->sdn_objname[i] = rand();
+		dn->sdn_objname[i] = rnd();
 	dn->sdn_add.a_len = RAND_BOOL();
-	dn->sdn_add.a_addr[0] = rand();
-	dn->sdn_add.a_addr[1] = rand();
+	dn->sdn_add.a_addr[0] = rnd();
+	dn->sdn_add.a_addr[1] = rnd();
 	*addr = (struct sockaddr *) dn;
 	*addrlen = sizeof(struct sockaddr_dn);
 }
 
-void decnet_rand_socket(struct socket_triplet *st)
-{
-	if (RAND_BOOL()) {
-		st->type = SOCK_SEQPACKET;
-		st->protocol = DNPROTO_NSP;
-	} else {
-		st->type = SOCK_STREAM;
-		st->protocol = rand() % PROTO_MAX;
-	}
-}
-
 static const unsigned int decnet_opts[] = {
 	SO_CONDATA, SO_CONACCESS, SO_PROXYUSR, SO_LINKINFO,
 	DSO_CONDATA, DSO_DISDATA, DSO_CONACCESS, DSO_ACCEPTMODE,
@@ -48,9 +37,23 @@ static const unsigned int decnet_opts[] = {
 	DSO_SERVICES, DSO_INFO
 };
 
-void decnet_setsockopt(struct sockopt *so)
+static void decnet_setsockopt(struct sockopt *so, __unused__ struct socket_triplet *triplet)
 {
+	so->level = SOL_DECNET;
 	so->optname = RAND_ARRAY(decnet_opts);
 
 	// TODO: set optlen correctly
 }
+
+static struct socket_triplet decnet_triplets[] = {
+	{ .family = PF_DECnet, .protocol = DNPROTO_NSP, .type = SOCK_SEQPACKET },
+	{ .family = PF_DECnet, .protocol = DNPROTO_NSP, .type = SOCK_STREAM },
+};
+
+const struct netproto proto_decnet = {
+	.name = "decnet",
+	.setsockopt = decnet_setsockopt,
+	.gen_sockaddr = decnet_gen_sockaddr,
+	.valid_triplets = decnet_triplets,
+	.nr_triplets = ARRAY_SIZE(decnet_triplets),
+};
