@@ -13,10 +13,17 @@ static const unsigned int tcp_opts[] = {
 	TCP_THIN_DUPACK, TCP_USER_TIMEOUT, TCP_REPAIR, TCP_REPAIR_QUEUE,
 	TCP_QUEUE_SEQ, TCP_REPAIR_OPTIONS, TCP_FASTOPEN, TCP_TIMESTAMP,
 	TCP_NOTSENT_LOWAT, TCP_CC_INFO, TCP_SAVE_SYN, TCP_SAVED_SYN,
-	TCP_REPAIR_WINDOW,
+	TCP_REPAIR_WINDOW, TCP_FASTOPEN_CONNECT, TCP_ULP, TCP_MD5SIG_EXT,
 };
 
 void tcp_setsockopt(struct sockopt *so, __unused__ struct socket_triplet *triplet)
 {
 	so->optname = RAND_ARRAY(tcp_opts);
+
+	if (so->optname == TCP_ULP) {
+		char *ptr = (char *) so->optval;
+
+		sprintf(ptr, "tls");
+		so->optlen = sizeof("tls");
+	}
 }
