@@ -11,7 +11,7 @@
 #include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
-void irda_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
+static void irda_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 {
 	struct sockaddr_irda *irda;
 	unsigned int i;
@@ -19,44 +19,37 @@ void irda_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	irda = zmalloc(sizeof(struct sockaddr_irda));
 
 	irda->sir_family = PF_IRDA;
-	irda->sir_lsap_sel = rand();
-	irda->sir_addr = rand();
+	irda->sir_lsap_sel = rnd();
+	irda->sir_addr = rnd();
 	for (i = 0; i < 25; i++)
-		irda->sir_name[i] = rand();
+		irda->sir_name[i] = rnd();
 	*addr = (struct sockaddr *) irda;
 	*addrlen = sizeof(struct sockaddr_irda);
 }
 
-void irda_rand_socket(struct socket_triplet *st)
-{
-	switch (rand() % 3) {
-
-	case 0: st->type = SOCK_STREAM;
-		st->protocol = rand() % PROTO_MAX;
-		break;
-
-	case 1: st->type = SOCK_SEQPACKET;
-		st->protocol = rand() % PROTO_MAX;
-		break;
-
-	case 2: st->type = SOCK_DGRAM;
-		if (RAND_BOOL())
-			st->protocol = IRDAPROTO_ULTRA;
-		else
-			st->protocol = IRDAPROTO_UNITDATA;
-		break;
-
-	default:break;
-	}
-}
-
 static const unsigned int irda_opts[] = {
 	IRLMP_ENUMDEVICES, IRLMP_IAS_SET, IRLMP_IAS_QUERY, IRLMP_HINTS_SET,
 	IRLMP_QOS_SET, IRLMP_QOS_GET, IRLMP_MAX_SDU_SIZE, IRLMP_IAS_GET,
 	IRLMP_IAS_DEL, IRLMP_HINT_MASK_SET, IRLMP_WAITDEVICE
 };
 
-void irda_setsockopt(struct sockopt *so)
+static void irda_setsockopt(struct sockopt *so, __unused__ struct socket_triplet *triplet)
 {
+	so->level = SOL_IRDA;
 	so->optname = RAND_ARRAY(irda_opts);
 }
+
+static struct socket_triplet irda_triplets[] = {
+	{ .family = PF_IRDA, .protocol = IRDAPROTO_UNITDATA, .type = SOCK_DGRAM },
+	{ .family = PF_IRDA, .protocol = IRDAPROTO_ULTRA, .type = SOCK_DGRAM },
+	{ .family = PF_IRDA, .protocol = 0, .type = SOCK_SEQPACKET },
+	{ .family = PF_IRDA, .protocol = 0, .type = SOCK_STREAM },
+};
+
+const struct netproto proto_irda = {
+	.name = "irda",
+	.setsockopt = irda_setsockopt,
+	.gen_sockaddr = irda_gen_sockaddr,
+	.valid_triplets = irda_triplets,
+	.nr_triplets = ARRAY_SIZE(irda_triplets),
+};
