@@ -1,13 +1,16 @@
 #include <sys/socket.h>
-#include "config.h"
 #include "net.h"
 #include "compat.h"
 
 const struct protoptr net_protocols[TRINITY_PF_MAX] = {
 	[PF_UNIX] = { .proto = &proto_unix },
 	[PF_INET] = { .proto = &proto_ipv4 },
+#ifdef USE_NETAX25
 	[PF_AX25] = { .proto = &proto_ax25 },
+#endif
+#ifdef USE_IPX
 	[PF_IPX] = { .proto = &proto_ipx },
+#endif
 #ifdef USE_APPLETALK
 	[PF_APPLETALK] = { .proto = &proto_appletalk },
 #endif
@@ -17,7 +20,9 @@ const struct protoptr net_protocols[TRINITY_PF_MAX] = {
 #endif
 	[PF_DECnet] = { .proto = &proto_decnet },
 	[PF_PACKET] = { .proto = &proto_packet },
+#ifdef USE_NETECONET
 	[PF_ECONET] = { .proto = &proto_econet },
+#endif
 #ifdef USE_RDS
 	[PF_RDS] = { .proto = &proto_rds },
 #endif
@@ -48,4 +53,6 @@ const struct protoptr net_protocols[TRINITY_PF_MAX] = {
 	[PF_ALG] = { .proto = &proto_alg },
 #endif
 	[PF_KCM] = { .proto = &proto_kcm },
+	[PF_QIPCRTR] = { .proto = &proto_qipcrtr },
+	[PF_SMC] = { .proto = &proto_smc },
 };
