@@ -8,6 +8,7 @@
 
 #include "bdevs.h"
 #include "child.h"
+#include "ftrace.h"
 #include "log.h"
 #include "net.h"
 #include "params.h"
@@ -17,6 +18,7 @@
 #include "tables.h"
 #include "taint.h"
 #include "trinity.h"	// progname
+#include "udp.h"
 
 bool set_debug = FALSE;
 bool do_specific_syscall = FALSE;
@@ -37,7 +39,6 @@ bool show_syscall_list = FALSE;
 bool show_ioctl_list = FALSE;
 unsigned char quiet_level = 0;
 bool verbose = FALSE;
-bool monochrome = FALSE;
 bool dangerous = FALSE;
 bool dropprivs = FALSE;
 bool do_syslog = FALSE;
@@ -56,12 +57,14 @@ char *specific_domain_optarg = NULL;
 char *victim_path = NULL;
 
 int logging = LOGGING_FILES;
+char *logging_args = NULL;
 
 unsigned int kernel_taint_mask = 0xFFFFFFFF;
 bool kernel_taint_param_occured = FALSE;
 
 void enable_disable_fd_usage(void)
 {
+	//TODO: Build this dynamically
 	outputerr(" --enable-fds/--disable-fds= {sockets,pipes,perf,epoll,eventfd,pseudo,timerfd,testfile,memfd,drm}\n");
 }
 
@@ -75,12 +78,12 @@ static void usage(void)
 	outputerr(" --dropprivs, -X: if run as root, switch to nobody [EXPERIMENTAL]\n");
 	outputerr(" --exclude,-x: don't call a specific syscall\n");
 	enable_disable_fd_usage();
+	outputerr(" --ftrace-dump-file: specify file that ftrace buffer gets dumped to if kernel becomes tainted.\n");
 	outputerr(" --group,-g = {vfs,vm}: only run syscalls from a certain group.\n");
 	outputerr(" --ioctls,-I: list all ioctls.\n");
 	outputerr(" --kernel_taint, -T: controls which kernel taint flags should be considered, for more details refer to README file. \n");
 	outputerr(" --list,-L: list all syscalls known on this architecture.\n");
-	outputerr(" --logging,-l: (off=disable logging).\n");
-	outputerr(" --monochrome,-m: don't output ANSI codes\n");
+	outputerr(" --logging,-l [off, <dir>, <hostname>] : disable logging to files, log to a directory, or log over udp to a remote trinity server.\n");
 	outputerr(" --domain,-P: specify specific network domain for sockets.\n");	//FIXME: P used to be 'proto' pick something better.
 	outputerr(" --no_domain,-E: specify network domains to be excluded from testing.\n");
 	outputerr(" --quiet,-q: less output.\n");
@@ -96,7 +99,7 @@ static void usage(void)
 	exit(EXIT_SUCCESS);
 }
 
-static const char paramstr[] = "a:b:c:C:dDE:g:hIl:LmN:P:qr:s:ST:V:vx:X";
+static const char paramstr[] = "a:b:c:C:dDE:g:hIl:LN:P:qr:s:ST:V:vx:X";
 
 static const struct option longopts[] = {
 	{ "arch", required_argument, NULL, 'a' },
@@ -110,13 +113,13 @@ static const struct option longopts[] = {
 	{ "dry-run", no_argument, NULL, 0 },
 	{ "enable-fds", required_argument, NULL, 0 },
 	{ "exclude", required_argument, NULL, 'x' },
+	{ "ftrace-dump-file", required_argument, NULL, 0 },
 	{ "group", required_argument, NULL, 'g' },
 	{ "kernel_taint", required_argument, NULL, 'T' },
 	{ "help", no_argument, NULL, 'h' },
 	{ "list", no_argument, NULL, 'L' },
 	{ "ioctls", no_argument, NULL, 'I' },
 	{ "logging", required_argument, NULL, 'l' },
-	{ "monochrome", no_argument, NULL, 'm' },
 	{ "no_domain", required_argument, NULL, 'E' },
 	{ "domain", required_argument, NULL, 'P' },
 	{ "quiet", no_argument, NULL, 'q' },
@@ -128,6 +131,31 @@ static const struct option longopts[] = {
 	{ "victims", required_argument, NULL, 'V' },
 	{ NULL, 0, NULL, 0 } };
 
+static void parse_logging(void)
+{
+	struct stat sb;
+	int ret;
+
+	if (!strcmp(optarg, "off")) {
+		logging = LOGGING_DISABLED;
+		return;
+	}
+
+	logging_args = strdup(optarg);
+
+	// Is the param a directory ?
+	ret = stat(logging_args, &sb);
+	if (ret == 0) {
+		if (S_ISDIR(sb.st_mode)) {
+			logging = LOGGING_FILES;
+			return;
+		}
+	}
+
+	// try the arg as a hostname.
+	logging = LOGGING_UDP;
+}
+
 void parse_args(int argc, char *argv[])
 {
 	int opt;
@@ -210,26 +238,13 @@ void parse_args(int argc, char *argv[])
 			break;
 
 		case 'l':
-			if (!strncmp(optarg, "off", 3))
-				logging = LOGGING_DISABLED;
+			parse_logging();
 			break;
 
 		case 'L':
 			show_syscall_list = TRUE;
 			break;
 
-		case 'm':
-			monochrome = TRUE;
-			memset(&ANSI_RED, 0, 1);
-			memset(&ANSI_GREEN, 0, 1);
-			memset(&ANSI_YELLOW, 0, 1);
-			memset(&ANSI_BLUE, 0, 1);
-			memset(&ANSI_MAGENTA, 0, 1);
-			memset(&ANSI_CYAN, 0, 1);
-			memset(&ANSI_WHITE, 0, 1);
-			memset(&ANSI_RESET, 0, 1);
-			break;
-
 		/* Set number of syscalls to do */
 		case 'N':
 			syscalls_todo = strtoll(optarg, NULL, 10);
@@ -294,7 +309,10 @@ void parse_args(int argc, char *argv[])
 			break;
 
 		case 'X':
-			dropprivs = TRUE;
+			if (getuid() == 0)
+				dropprivs = TRUE;
+			else
+				outputstd("Already running unprivileged, can't drop privs\n");
 			break;
 
 		case 0:
@@ -304,11 +322,14 @@ void parse_args(int argc, char *argv[])
 			if (strcmp("disable-fds", longopts[opt_index].name) == 0)
 				process_fds_param(optarg, FALSE);
 
+			if (strcmp("dry-run", longopts[opt_index].name) == 0)
+				dry_run = TRUE;
+
 			if (strcmp("enable-fds", longopts[opt_index].name) == 0)
 				process_fds_param(optarg, TRUE);
 
-			if (strcmp("dry-run", longopts[opt_index].name) == 0)
-				dry_run = TRUE;
+			if (strcmp("ftrace-dump-file", longopts[opt_index].name) == 0)
+				ftracedumpname = strdup(optarg);
 
 			if (strcmp("show-unannotated", longopts[opt_index].name) == 0)
 				show_unannotated = TRUE;
