@@ -6,7 +6,6 @@
 #include <sys/mman.h>	// mprotect
 
 #include "arch.h"	// KERNEL_ADDR etc
-#include "log.h"
 #include "random.h"
 #include "sanitise.h"
 #include "maps.h"
@@ -34,6 +33,8 @@ retry:	tries++;
 		map->prot = PROT_READ | PROT_WRITE;
 	} else {
 		obj = get_random_object(OBJ_SYSV_SHM, OBJ_GLOBAL);
+		if (obj == NULL)
+			goto retry;
 		if (obj->sysv_shm.size < size)
 			goto retry;
 		addr = obj->sysv_shm.ptr;
@@ -112,7 +113,10 @@ struct iovec * alloc_iovec(unsigned int num)
 		struct map *map = get_map();
 
 		iov[i].iov_base = map->ptr;
-		iov[i].iov_len = rnd() % map->size;
+		if (RAND_BOOL())
+			iov[i].iov_len = 20;
+		else
+			iov[i].iov_len = rnd() % map->size;
 	}
 
 	return iov;
