@@ -7,7 +7,7 @@
 cd $TRINITY_TMP
 
 NR_CPUS=$(nproc)
-NR_PROCESSES=$(($NR_CPUS * 2))
+NR_PROCESSES=$(($NR_CPUS * 16))
 
 while [ 1 ];
 do
@@ -25,7 +25,7 @@ do
 
   rm -f trinity.socketcache
 
-  MALLOC_CHECK_=2 ../trinity -q -l off -C $NR_PROCESSES $DROPPRIVS -N 1000000
+  MALLOC_CHECK_=2 ../trinity -q -l wopr -C $NR_PROCESSES $DROPPRIVS -N 1000000 -E SMC -a64
 
   chmod 755 $TRINITY_TMP
   popd > /dev/null
