@@ -5,6 +5,7 @@
 #include <errno.h>
 #include <string.h>
 #include <signal.h>
+#include <unistd.h>
 #include <sys/prctl.h>
 #include <sys/syscall.h>
 #include <sys/types.h>
@@ -12,6 +13,7 @@
 
 #include "arch.h"
 #include "child.h"
+#include "ftrace.h"
 #include "params.h"
 #include "pids.h"
 #include "random.h"
@@ -19,8 +21,10 @@
 #include "sanitise.h"
 #include "shm.h"
 #include "syscall.h"
-#include "log.h"
 #include "tables.h"
+#include "taint.h"
+#include "trinity.h"
+#include "udp.h"
 #include "uid.h"
 #include "utils.h"
 
@@ -113,6 +117,14 @@ static void __do_syscall(struct syscallrecord *rec, enum syscallstate state)
 		} else {
 			ret = syscall32(call, rec->a1, rec->a2, rec->a3, rec->a4, rec->a5, rec->a6);
 		}
+
+		/* If we became tainted, get out as fast as we can. */
+		if (is_tainted() == TRUE) {
+			stop_ftrace();
+			panic(EXIT_KERNEL_TAINTED);
+			_exit(EXIT_FAILURE);
+		}
+
 		if (needalarm)
 			(void)alarm(0);
 	}
@@ -147,7 +159,7 @@ static void do_extrafork(struct syscallrecord *rec)
 
 	/* misc failure. */
 	if (extrapid == -1) {
-		debugf("Couldn't fork grandchild: %s\n", strerror(errno));
+		//debugf("Couldn't fork grandchild: %s\n", strerror(errno));
 		return;
 	}
 
@@ -155,6 +167,7 @@ static void do_extrafork(struct syscallrecord *rec)
 	if (pid_alive(extrapid) == TRUE)
 		usleep(100);
 
+	lock(&rec->lock);
 	while (pid == 0) {
 		int childstatus;
 
@@ -163,14 +176,30 @@ static void do_extrafork(struct syscallrecord *rec)
 			kill(extrapid, SIGKILL);
 		usleep(1000);
 	}
+	unlock(&rec->lock);
 }
 
 
 void do_syscall(struct syscallrecord *rec)
 {
 	struct syscallentry *entry;
+	struct msg_syscallprep scmsg;
+	struct childdata *child = this_child();
 	unsigned int call;
 
+	init_msgchildhdr(&scmsg.hdr, SYSCALL_PREP, pids[child->num], child->num);
+	scmsg.sequence_nr = child->op_nr;
+	scmsg.nr = rec->nr;
+	scmsg.is32bit = rec->do32bit;
+	scmsg.a1 = rec->a1;
+	scmsg.a2 = rec->a2;
+	scmsg.a3 = rec->a3;
+	scmsg.a4 = rec->a4;
+	scmsg.a5 = rec->a5;
+	scmsg.a6 = rec->a6;
+	rec->tp = scmsg.hdr.tp;
+	sendudp((char *) &scmsg, sizeof(scmsg));
+
 	call = rec->nr;
 	entry = syscalls[call].entry;
 
@@ -179,6 +208,9 @@ void do_syscall(struct syscallrecord *rec)
 	else
 		 /* common-case, do the syscall in this child process. */
 		__do_syscall(rec, BEFORE);
+
+	/* timestamp again for when we returned */
+	clock_gettime(CLOCK_MONOTONIC, &rec->tp);
 }
 
 /*
@@ -219,8 +251,17 @@ static void generic_post(const enum argtype type, unsigned long reg)
 void handle_syscall_ret(struct syscallrecord *rec)
 {
 	struct syscallentry *entry;
+	struct msg_syscallresult scmsg;
+	struct childdata *child = this_child();
 	unsigned int call;
 
+	init_msgchildhdr(&scmsg.hdr, SYSCALL_RESULT, pids[child->num], child->num);
+	scmsg.hdr.tp = rec->tp;
+	scmsg.sequence_nr = child->op_nr;
+	scmsg.retval = rec->retval;
+	scmsg.errno_post = rec->errno_post;
+	sendudp((char *) &scmsg, sizeof(scmsg));
+
 	call = rec->nr;
 	entry = syscalls[call].entry;
 
@@ -228,6 +269,7 @@ void handle_syscall_ret(struct syscallrecord *rec)
 		int err = rec->errno_post;
 
 		/* only check syscalls that completed. */
+		//FIXME: how else would we get here?
 		if (rec->state == AFTER) {
 			if (err == ENOSYS)
 				deactivate_enosys(rec, entry, call);
@@ -236,7 +278,13 @@ void handle_syscall_ret(struct syscallrecord *rec)
 			if (err < NR_ERRNOS) {
 				entry->errnos[err]++;
 			} else {
-				printf("errno out of range: %d:%s\n", err, strerror(err));
+				// "These should never be seen by user programs."
+				// But trinity isn't a 'normal' user program, we're doing
+				// stuff that libc hides from apps.
+				if (err < 512 || err > 530)
+					printf("errno out of range after doing %s: %d:%s\n",
+						entry->name,
+						err, strerror(err));
 			}
 			shm->stats.failures++;
 		}
