@@ -10,6 +10,10 @@
 
 #include "sanitise.h"
 
+static unsigned long kexec_file_load_flags[] = {
+	KEXEC_FILE_UNLOAD, KEXEC_FILE_ON_CRASH, KEXEC_FILE_NO_INITRAMFS,
+};
+
 struct syscallentry syscall_kexec_file_load = {
 	.name = "kexec_file_load",
 	.num_args = 5,
@@ -23,11 +27,5 @@ struct syscallentry syscall_kexec_file_load = {
 	.arg4type = ARG_ADDRESS,
 	.arg5name = "flags",
 	.arg5type = ARG_LIST,
-	.arg5list = {
-		.num = 2,
-		.values = {
-			KEXEC_FILE_UNLOAD, KEXEC_FILE_ON_CRASH,
-			KEXEC_FILE_NO_INITRAMFS,
-		},
-	},
+	.arg5list = ARGLIST(kexec_file_load_flags),
 };
