@@ -10,7 +10,6 @@
 #include <sys/types.h>
 #include <dirent.h>
 #include <errno.h>
-#include "log.h"
 #include "maps.h"
 #include "perf.h"
 #include "perf_event.h"
@@ -880,6 +879,8 @@ static long long random_sample_type(void)
 		sample_type |= PERF_SAMPLE_TRANSACTION;
 	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_REGS_INTR;
+	if (RAND_BOOL())
+		sample_type |= PERF_SAMPLE_PHYS_ADDR;
 
 	return sample_type;
 }
@@ -959,14 +960,6 @@ static long long random_branch_sample_type(void)
 		branch_sample |= PERF_SAMPLE_BRANCH_ANY_RETURN;
 	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_IND_CALL;
-	if (RAND_BOOL())
-		branch_sample |= PERF_SAMPLE_BRANCH_COND;
-	if (RAND_BOOL())
-		branch_sample |= PERF_SAMPLE_BRANCH_CALL_STACK;
-	if (RAND_BOOL())
-		branch_sample |= PERF_SAMPLE_BRANCH_IND_JUMP;
-	if (RAND_BOOL())
-		branch_sample |= PERF_SAMPLE_BRANCH_CALL;
 
 	/* Transactional Memory Types */
 	if (RAND_BOOL())
@@ -976,6 +969,23 @@ static long long random_branch_sample_type(void)
 	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_NO_TX;
 
+
+	if (RAND_BOOL())
+		branch_sample |= PERF_SAMPLE_BRANCH_COND;
+	if (RAND_BOOL())
+		branch_sample |= PERF_SAMPLE_BRANCH_CALL_STACK;
+	if (RAND_BOOL())
+		branch_sample |= PERF_SAMPLE_BRANCH_IND_JUMP;
+	if (RAND_BOOL())
+		branch_sample |= PERF_SAMPLE_BRANCH_CALL;
+	if (RAND_BOOL())
+		branch_sample |= PERF_SAMPLE_BRANCH_NO_FLAGS;
+	if (RAND_BOOL())
+		branch_sample |= PERF_SAMPLE_BRANCH_NO_CYCLES;
+	if (RAND_BOOL())
+		branch_sample |= PERF_SAMPLE_BRANCH_TYPE_SAVE;
+
+
 	return branch_sample;
 }
 
