@@ -2,10 +2,8 @@
  * SYSCALL_DEFINE5(prctl, int, option, unsigned long, arg2, unsigned long, arg3,
 	 unsigned long, arg4, unsigned long, arg5)
  */
-#include "config.h"
 
 #include <stdlib.h>
-#include <linux/prctl.h>
 #ifdef USE_SECCOMP
 #include <linux/seccomp.h>
 #endif
@@ -45,9 +43,11 @@ static int prctl_opts[] = {
 #ifdef USE_SECCOMP
 static void do_set_seccomp(struct syscallrecord *rec)
 {
-	unsigned long *optval = NULL, optlen = 0;
+	unsigned long *optval = NULL, __unused__ optlen = 0;
 
+#ifdef USE_BPF
 	bpf_gen_seccomp(&optval, &optlen);
+#endif
 
 	rec->a2 = SECCOMP_MODE_FILTER;
 	rec->a3 = (unsigned long) optval;
@@ -87,4 +87,5 @@ struct syscallentry syscall_prctl = {
 	.arg4name = "arg4",
 	.arg5name = "arg5",
 	.sanitise = sanitise_prctl,
+	//TODO: .post that free's bpf & bpf->filter
 };
