@@ -3,7 +3,7 @@
  */
 #include "sanitise.h"
 
-struct syscall syscall_restart_syscall = {
+struct syscallentry syscall_restart_syscall = {
 	.name = "restart_syscall",
 	.num_args = 0,
 	.flags = AVOID_SYSCALL,
