@@ -5,6 +5,10 @@
 #include <fcntl.h>
 #include "sanitise.h"
 
+static unsigned long utimensat_flags[] = {
+	AT_SYMLINK_NOFOLLOW,
+};
+
 struct syscallentry syscall_utimensat = {
 	.name = "utimensat",
 	.num_args = 4,
@@ -16,9 +20,6 @@ struct syscallentry syscall_utimensat = {
 	.arg3type = ARG_ADDRESS,
 	.arg4name = "flags",
 	.arg4type = ARG_LIST,
-	.arg4list = {
-		.num = 1,
-		.values = { AT_SYMLINK_NOFOLLOW },
-	},
+	.arg4list = ARGLIST(utimensat_flags),
 	.flags = NEED_ALARM,
 };
