@@ -10,10 +10,28 @@
 #include "random.h"
 #include "sysv-shm.h"
 #include "objects.h"
+#include "udp.h"
 #include "utils.h"
 
+static void dump_sysv_shm(struct object *obj, bool global)
+{
+	struct msg_objcreatedshm objmsg;
+
+	output(0, "sysv_shm: id:%u size:%d flags:%x ptr:%p\n",
+		obj->sysv_shm.id, obj->sysv_shm.size,
+		obj->sysv_shm.flags, obj->sysv_shm.ptr);
+
+	init_msgobjhdr(&objmsg.hdr, OBJ_CREATED_SHM, global, obj);
+	objmsg.ptr = obj->sysv_shm.ptr;
+	objmsg.id = obj->sysv_shm.id;
+	objmsg.size = obj->sysv_shm.size;
+	objmsg.flags = obj->sysv_shm.flags;
+	sendudp((char *) &objmsg, sizeof(objmsg));
+}
+
 void create_sysv_shms(void)
 {
+	struct objhead *head;
 	unsigned int i;
 	int shmget_flags[] = {
 		0,	// Just CREAT|EXCL
@@ -24,6 +42,9 @@ void create_sysv_shms(void)
 		SHM_HUGETLB|SHM_HUGE_1GB|SHM_NORESERVE,
 	};
 
+	head = get_objhead(OBJ_GLOBAL, OBJ_SYSV_SHM);
+	head->dump = dump_sysv_shm;
+
 	for (i = 0; i < ARRAY_SIZE(shmget_flags); i++) {
 		void *p;
 		struct object *obj;
@@ -52,5 +73,4 @@ void create_sysv_shms(void)
 		if (p != (void *) -1)
 			obj->sysv_shm.ptr = p;
 	}
-	//dump_objects(OBJ_GLOBAL, OBJ_SYSV_SHM);
 }
