@@ -9,7 +9,6 @@
 
 #include "arch.h"
 #include "arch-syscalls.h"
-#include "log.h"
 #include "params.h"
 #include "syscall.h"
 #include "shm.h"
@@ -565,6 +564,14 @@ void display_enabled_syscalls(void)
 		display_enabled_syscalls_uniarch();
 }
 
+void log_enabled_syscalls(void)
+{
+	if (biarch == TRUE)
+		log_enabled_syscalls_biarch();
+	else
+		log_enabled_syscalls_uniarch();
+}
+
 static void enable_random_syscalls(void)
 {
 	unsigned int i;
@@ -647,6 +654,7 @@ int munge_tables(void)
 
 	if (verbose == TRUE)
 		display_enabled_syscalls();
+	log_enabled_syscalls();
 
 	if (validate_syscall_tables() == FALSE) {
 		outputstd("No syscalls were enabled!\n");
@@ -665,15 +673,14 @@ int munge_tables(void)
  */
 struct syscallentry * get_syscall_entry(unsigned int callno, bool do32)
 {
-	unsigned int offset = callno - SYSCALL_OFFSET;
 	if (biarch == FALSE)
-		return syscalls[offset].entry;
+		return syscalls[callno].entry;
 
 	/* biarch case */
 	if (do32 == TRUE)
-		return syscalls_32bit[offset].entry;
+		return syscalls_32bit[callno].entry;
 	else
-		return syscalls_64bit[offset].entry;
+		return syscalls_64bit[callno].entry;
 }
 
 /*
