@@ -4,11 +4,12 @@
 #include <sys/prctl.h>
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <unistd.h>
 
 #include "arch.h"
-#include "config.h"	// for VERSION
 #include "fd.h"
 #include "files.h"
+#include "ftrace.h"
 #include "ioctls.h"
 #include "log.h"
 #include "maps.h"
@@ -24,6 +25,7 @@
 #include "tables.h"
 #include "taint.h"
 #include "trinity.h"
+#include "udp.h"
 #include "uid.h"
 #include "version.h"
 
@@ -110,9 +112,6 @@ int main(int argc, char* argv[])
 	num_online_cpus = sysconf(_SC_NPROCESSORS_ONLN);
 	max_children = num_online_cpus * 4;	/* possibly overridden in params. */
 
-	if (init_random() == FALSE)
-		exit(EXIT_FAILURE);
-
 	select_syscall_tables();
 
 	create_shm();
@@ -123,13 +122,9 @@ int main(int argc, char* argv[])
 
 	change_tmp_dir();
 
-	init_logging();
-
 	init_shm();
 
-	kernel_taint_initial = check_tainted();
-	if (kernel_taint_initial != 0)
-		output(0, "Kernel was tainted on startup. Will ignore flags that are already set.\n");
+	init_taint_checking();
 
 	if (munge_tables() == FALSE) {
 		ret = EXIT_FAILURE;
@@ -160,6 +155,8 @@ int main(int argc, char* argv[])
 
 	pids_init();
 
+	init_logging();
+
 	init_object_lists(OBJ_GLOBAL);
 
 	setup_initial_mappings();
@@ -184,12 +181,17 @@ int main(int argc, char* argv[])
 		_exit(EXIT_FAILURE);
 	}
 
+	setup_ftrace();
+
 	main_loop();
 
 	destroy_global_objects();
 
+	if (is_tainted() == TRUE)
+		stop_ftrace();
+
 	output(0, "Ran %ld syscalls. Successes: %ld  Failures: %ld\n",
-		shm->stats.op_count - 1, shm->stats.successes, shm->stats.failures);
+		shm->stats.op_count, shm->stats.successes, shm->stats.failures);
 	if (show_stats == TRUE)
 		dump_stats();
 
